==> mx-bootrepair_21.3.03.tar.xz: mx-bootrepair-21.3.03/translations/mx-boot-repair_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>MX Reparar Inicio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>MX Reparar Inicio es un programa para reinstalar el gestor de arranque GRUB en el ESP (Partición de Sistema EFI), en el Registro de Inicialización del Disco (MBR) o en la partición root. Provee opciones para reconstruir la configuración de GRUB, respaldar y/o restaurar el MBR o el PBR (root). </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>¿Qué desea hacer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Respaldar MBR o PBR (sólo para GRUB antiguo)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Reinstalar el gestor de arranque GRUB en ESP, MBR o PBR (root)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Reparar archivo de configuración de GRUB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Restaurar del respaldo el MBR o el PBR (sólo para GRUB antiguo)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <location filename="../mainwindow.cpp" line="483"/>
        <source>Select Boot Method</source>
        <translation>Escoger metódo de Inicialización</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Master Boot Record</source>
        <translation>Registro de Inicialización del Disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Root (Registro de Inicialización de la Partición)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <location filename="../mainwindow.cpp" line="486"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.cpp" line="485"/>
        <source>Install on:</source>
        <translation>Instalar en:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>Location:</source>
        <translation>Ubicación:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>Select root location:</source>
        <translation>Seleccione la ubicación de root:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>EFI System Partition</source>
        <translation>Sistema de partición EFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="293"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="472"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancelar los cambios y luego salir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="526"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="552"/>
        <source>Apply any changes</source>
        <translation>Aplicar los cambios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="555"/>
        <location filename="../mainwindow.cpp" line="71"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>GRUB está siendo instalado en el dispositivo %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <location filename="../mainwindow.cpp" line="130"/>
        <location filename="../mainwindow.cpp" line="192"/>
        <location filename="../mainwindow.cpp" line="216"/>
        <location filename="../mainwindow.cpp" line="322"/>
        <location filename="../mainwindow.cpp" line="396"/>
        <location filename="../mainwindow.cpp" line="419"/>
        <location filename="../mainwindow.cpp" line="525"/>
        <location filename="../mainwindow.cpp" line="532"/>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <location filename="../mainwindow.cpp" line="192"/>
        <source>Could not create a temporary folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="130"/>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>No se pudo establecer un ambiente de chroot.
Por favor revise la ubicación seleccionada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>La configuración de GRUB (grub.cfg) esta siendo reconstruida. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Respaldando MBR o PBR desde el dispositivo %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source>You are going to write the content of </source>
        <translation>Va a escribir el contenido de </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source> to </source>
        <translation>a</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source>

Are you sure?</source>
        <translation>

¿Está seguro?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Restaurando MBR/PBR desde un respaldo al dispositivo %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>No se pudo encontrar la partición de sistema EFI (ESP) en ningún disco del sistema. Favor crear un ESP e intentar de nuevo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>Select %1 location:</source>
        <translation>Seleccione la ubicación de %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Back</source>
        <translation>Volver</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="391"/>
        <source>Success</source>
        <translation>Éxito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>El Proceso terminó con exito.&lt;p&gt;&lt;b&gt;¿Desea salir de MX Reparar inicio?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Proceso finalizado.  Ocurrieron errores.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Ingrese la contrasela para desbloquear la partición cifrada %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Sorry, could not open %1 LUKS container</source>
        <translation>Lo sentimos, no se pudo abrir el contenedor LUKS %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>Select GRUB location</source>
        <translation>Seleccione la ubicación para GRUB.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="505"/>
        <source>Select Item to Back Up</source>
        <translation>Seleccione ítem para Respaldar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>Select Item to Restore</source>
        <translation>Seleccione ítem para Restaurar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>Select backup file name</source>
        <translation>Seleccionar nombre del archivo de respaldo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="525"/>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>No file was selected.</source>
        <translation>Ningún archivo fue seleccionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="530"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Escoger archivo de respaldo de MBR o PBR</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>About %1</source>
        <translation>Acerca de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Programa simple para reparar el arranque en MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="554"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="555"/>
        <source>%1 License</source>
        <translation>%1 Licencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>%1 Help</source>
        <translation>%1 Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>Sorry, could not mount %1 partition</source>
        <translation>Lo sentimos, no se pudo montar la partición %1</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Debe ejecutar este programa como root.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Error</source>
        <translation type="unfinished">Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-bootrepair_22.76.02.tar.xz: mx-bootrepair-22.76.02/translations/mx-boot-repair_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>MX Reparar Inicio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>MX Reparar Inicio es un programa para reinstalar el gestor de arranque GRUB en el ESP (Partición de Sistema EFI), en el Registro de Inicialización del Disco (MBR) o en la partición root. Provee opciones para reconstruir la configuración de GRUB, respaldar y/o restaurar el MBR o el PBR (root). </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>¿Qué desea hacer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Respaldar MBR o PBR (sólo para GRUB antiguo)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Reinstalar el gestor de arranque GRUB en ESP, MBR o PBR (root)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Reparar archivo de configuración de GRUB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Restaurar del respaldo el MBR o el PBR (sólo para GRUB antiguo)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Select Boot Method</source>
        <translation>Escoger metódo de Inicialización</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Master Boot Record</source>
        <translation>Registro de Inicialización del Disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Root (Registro de Inicialización de la Partición)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.cpp" line="538"/>
        <source>Install on:</source>
        <translation>Instalar en:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>Location:</source>
        <translation>Ubicación:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.cpp" line="547"/>
        <source>Select root location:</source>
        <translation>Seleccione la ubicación de root:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>EFI System Partition</source>
        <translation>Sistema de partición EFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="293"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="472"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancelar los cambios y luego salir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="526"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="552"/>
        <source>Apply any changes</source>
        <translation>Aplicar los cambios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="555"/>
        <location filename="../mainwindow.cpp" line="79"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>GRUB está siendo instalado en el dispositivo %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="119"/>
        <location filename="../mainwindow.cpp" line="148"/>
        <location filename="../mainwindow.cpp" line="213"/>
        <location filename="../mainwindow.cpp" line="245"/>
        <location filename="../mainwindow.cpp" line="354"/>
        <location filename="../mainwindow.cpp" line="449"/>
        <location filename="../mainwindow.cpp" line="473"/>
        <location filename="../mainwindow.cpp" line="578"/>
        <location filename="../mainwindow.cpp" line="585"/>
        <location filename="../mainwindow.cpp" line="642"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="119"/>
        <location filename="../mainwindow.cpp" line="213"/>
        <source>Could not create a temporary folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="148"/>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>No se pudo establecer un ambiente de chroot.
Por favor revise la ubicación seleccionada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>La configuración de GRUB (grub.cfg) esta siendo reconstruida. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Respaldando MBR o PBR desde el dispositivo %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>You are going to write the content of </source>
        <translation>Va a escribir el contenido de </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="329"/>
        <source> to </source>
        <translation>a</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="329"/>
        <source>

Are you sure?</source>
        <translation>

¿Está seguro?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Restaurando MBR/PBR desde un respaldo al dispositivo %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="354"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>No se pudo encontrar la partición de sistema EFI (ESP) en ningún disco del sistema. Favor crear un ESP e intentar de nuevo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>Select %1 location:</source>
        <translation>Seleccione la ubicación de %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Back</source>
        <translation>Volver</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>Success</source>
        <translation>Éxito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>El Proceso terminó con exito.&lt;p&gt;&lt;b&gt;¿Desea salir de MX Reparar inicio?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="449"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Proceso finalizado.  Ocurrieron errores.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="466"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Ingrese la contrasela para desbloquear la partición cifrada %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>Sorry, could not open %1 LUKS container</source>
        <translation>Lo sentimos, no se pudo abrir el contenedor LUKS %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="546"/>
        <source>Select GRUB location</source>
        <translation>Seleccione la ubicación para GRUB.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <source>Select Item to Back Up</source>
        <translation>Seleccione ítem para Respaldar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="565"/>
        <source>Select Item to Restore</source>
        <translation>Seleccione ítem para Restaurar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="576"/>
        <source>Select backup file name</source>
        <translation>Seleccionar nombre del archivo de respaldo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>No file was selected.</source>
        <translation>Ningún archivo fue seleccionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Escoger archivo de respaldo de MBR o PBR</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="602"/>
        <source>About %1</source>
        <translation>Acerca de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="604"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="605"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Programa simple para reparar el arranque en MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="607"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="608"/>
        <source>%1 License</source>
        <translation>%1 Licencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>%1 Help</source>
        <translation>%1 Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="642"/>
        <source>Sorry, could not mount %1 partition</source>
        <translation>Lo sentimos, no se pudo montar la partición %1</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>License</source>
        <translation type="vanished">Licencia</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Registro de cambios</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Cerrar</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Debe ejecutar este programa como root.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Error</source>
        <translation type="unfinished">Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation type="unfinished">Licencia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation type="unfinished">Registro de cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="61"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Cerrar</translation>
    </message>
</context>
</TS>
